.. wordle-game documentation master file, created by
   sphinx-quickstart on Tue Feb  1 19:17:33 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to wordle-game's documentation!
=======================================


Guide
-----
.. toctree::
   
   cli

Modules
-------
.. toctree::

   wordle
   solver


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
